import java.awt.geom.Point2D;
import java.awt.Rectangle;
import java.awt.Shape;

/**
 * Zeichnet ein Rechteck auf die Leinwand.
 * 
 * @author Bernd Gramlich nach einer Vorlage von Michael Koelling und David J. Barnes 
 * @version 2014-04-06
 */
public class Rechteck
{
    // Attribute
    private int positionX;
    private int positionY;
    private int breite;
    private int hoehe;
    private String farbe;
    private boolean sichtbar;

    /**
     * Konstruktor der Klasse Rechteck.
     * Erzeugt ein neues Rechteck in Standardgroesse und Standardfarbe.
     */
    public Rechteck ()
    {
        breite        = 50;
        hoehe         = 140;
        farbe         = "grau";
        
        werdeSichtbar ();
    }

    /**
     * Mache dieses Rechteck sichtbar.
     */
    public void werdeSichtbar ()
    {
        sichtbar = true;
        zeichne ();
    }

    /**
     * Mache dieses Rechteck unsichtbar.
     */
    public void werdeUnsichtbar ()
    {
        loesche ();
        sichtbar = false;
    }

    /**
     * Aendere die Breite des Rechtecks.
     */
    public void setzeBreite (int neueBreite)
    {
        breite = neueBreite;
        zeichne ();
    }

    /**
     * Aendere die Hoehe des Rechtecks.
     */
    public void setzeHoehe (int neueHoehe)
    {
        hoehe = neueHoehe;
        zeichne ();
    }

    /**
     * Aendere die Farbe dieses Rechtecks in 'neueFarbe'. Gueltige Angaben
	 * sind in der Methode setzeZeichenfarbe () der Klasse Leinwand
     * definiert. (Zuletzt waren das "blau", "gelb", "grau", "gruen", "lila",
     * "orange", "rot", "schwarz", "tuerkis" und "weiss".)
     */
    public void setzeFarbe (String neueFarbe)
    {
        farbe = neueFarbe;
        zeichne ();
    }

    /**
     * Nenne die Farbe dieses Rechtecks.
     */
    public String gibFarbe ()
    {
        return farbe;
    }

    /**
     * Pruefe, ob ein Punkt in diesem Rechteck enthalten ist.
     */
    public boolean enthaelt (Point2D punkt)
    {
        Shape form = Leinwand.gibLeinwand ().gibForm (this);

        if (null != form)
        {
            return form.contains (punkt);
        }
        else
        {
            return false;
        }
    }

    /**
     * Aendere die Position dieses Rechtecks.
     */
    public void setzePosition (int neuePositionX, int neuePositionY)
    {
        positionX = neuePositionX;
        positionY = neuePositionY;
        zeichne ();
    }		

    /**
     * Zeichne dieses Rechteck auf die Leinwand.
     */
    private void zeichne ()
    {
        if (sichtbar)
        {
            Leinwand leinwand = Leinwand.gibLeinwand ();
            leinwand.zeichne (this, farbe, new Rectangle (positionX,
                    positionY, breite, hoehe));
        }
    }

    /**
     * Loesche dieses Rechteck von der Leinwand.
     */
    private void loesche ()
    {
        if (sichtbar)
        {
            Leinwand leinwand = Leinwand.gibLeinwand ();
            leinwand.entferne (this);
        }
    }   
}